<?php

namespace Drupal\node_save_popup\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a block with a confirm save text.
 *
 * @Block(
 *   id = "confirm_save_popup_block",
 *   admin_label = @Translation("Confirm Save Popup Block"),
 * )
 */
class ConfirmSave extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->configFactory->get('node_save_popup.settings');
    $types = $config->get('confirm_save_types');
    $confirm_title = $config->get('confirm_save_title_value');
    $confirm_body = $config->get('confirm_save_body_value');
    $yes_text = $config->get('confirm_save_yes');
    $cancel_text = $config->get('confirm_save_cancel');

    return [
      '#theme' => 'confirm_save',
      '#attached' => [
        'library' => [
          'node_save_popup/node-save-popup',
        ],
      ],
      '#data' => [
        'types' => $types,
        'confirm_title_text' => $confirm_title,
        'confirm_body_text' => $confirm_body,
        'yes_text' => $yes_text,
        'no_text' => $cancel_text,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIfHasPermission($account, 'access content');
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['node_save_popup_settings'] = $form_state->getValue('node_save_popup_settings');
  }

}
